@@ -39,24 +39,8 @@
 
 #include <gphoto2/gphoto2.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 #include "util.h"
 #include "library.h"
@@ -1911,6 +1895,7 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	gp_widget_new (GP_WIDGET_TEXT, _("Camera Model"), &t);
 	gp_widget_set_name (t, "model");
 	gp_widget_set_value (t, camera->pl->ident);
+	gp_widget_set_readonly (t, 1);
 	gp_widget_append (section, t);
 
 	gp_widget_new (GP_WIDGET_TEXT, _("Date and Time"), &t);
@@ -1923,6 +1908,7 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	} else {
 		gp_widget_set_value (t, _("Error"));
 	}
+	gp_widget_set_readonly (t, 1);
 	gp_widget_append (section, t);
 
 	gp_widget_new (GP_WIDGET_TEXT, _("Firmware Version"), &t);
@@ -1930,6 +1916,7 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	sprintf (firm, "%i.%i.%i.%i", camera->pl->firmwrev[3], camera->pl->firmwrev[2],
 		 camera->pl->firmwrev[1], camera->pl->firmwrev[0]);
 	gp_widget_set_value (t, firm);
+	gp_widget_set_readonly (t, 1);
 	gp_widget_append (section, t);
 
 	canon_get_batt_status (camera, &pwr_status, &pwr_source, context);
@@ -1948,6 +1935,7 @@ camera_get_config (Camera *camera, CameraWidget **window, GPContext *context)
 	gp_widget_new (GP_WIDGET_TEXT, _("Power"), &t);
 	gp_widget_set_name (t, "power");
 	gp_widget_set_value (t, power_str);
+	gp_widget_set_readonly (t, 1);
 	gp_widget_append (section, t);
 
 
@@ -2391,7 +2379,7 @@ static int
 get_info_func (CameraFilesystem __unused__ *fs, const char *folder,
 	       const char *filename,
 	       CameraFileInfo * info,
-	       void __unused__ *data, GPContext __unused__ *context)
+	       void *data, GPContext *context)
 {
 	Camera *camera = data;
 	GP_DEBUG ("get_info_func() called for '%s'/'%s'", folder, filename);
