@@ -26,24 +26,8 @@
 
 #include <gphoto2/gphoto2.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 #include "library.h"
 #include "canon.h"
@@ -211,7 +195,7 @@ canon_serial_send (Camera *camera, const unsigned char *buf, int len, int sleep)
  * @gdev: serial port to use
  * @to:   timeout in milliseconds
  *
- * Sets the timeout, in miliseconds.
+ * Sets the timeout, in milliseconds.
  *
  */
 static void
