@@ -31,30 +31,16 @@
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
-#ifdef OS2
-#include <db.h>
-#endif
 
 #define GP_MODULE "digita"
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
-#include "gphoto2-endian.h"
+
+#include "libgphoto2/gphoto2-endian.h"
 #include "digita.h"
 
 #ifndef MAX
