@@ -29,7 +29,7 @@
 #include <string.h>
 
 #include <gphoto2/gphoto2.h>
-#include "gphoto2-endian.h"
+#include "libgphoto2/gphoto2-endian.h"
 
 #define GP_MODULE "dimera"
 #define debuglog(e) GP_DEBUG( "%s", (e))
