@@ -23,23 +23,12 @@
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
-#include <gphoto2-endian.h>
+#include <libgphoto2/gphoto2-endian.h>
+
+#include "libgphoto2/i18n.h"
 
 #include "docupen.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #if 0
 static const struct {
