@@ -25,27 +25,11 @@
 #include <string.h>
 #include <gphoto2/gphoto2.h>
 
+#include "libgphoto2/i18n.h"
+
 #include "dc210.h"
 #include "library.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 static int dc210_cmd_error = 0;
 static const char ppmheader[] = "P6\n96 72\n255\n";
