@@ -22,8 +22,8 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
 #include "config.h"
@@ -39,23 +39,11 @@
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
 
+#include "libgphoto2/i18n.h"
+
+
 #define GP_MODULE "pccam600"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
-
 
 #define QUALITY_LO   0x56
 #define QUALITY_ME   0x58
@@ -80,7 +68,7 @@ int camera_id(CameraText *id)
 }
 
 int camera_abilities(CameraAbilitiesList *list)
-{        
+{
   int i;
   CameraAbilities a;
   for(i=0; models[i].name; i++) {
@@ -93,22 +81,22 @@ int camera_abilities(CameraAbilitiesList *list)
     a.usb_product = models[i].idProduct;
     a.operations        = 	GP_OPERATION_NONE;
     a.folder_operations = 	GP_FOLDER_OPERATION_NONE;
-    a.file_operations   =     GP_FILE_OPERATION_DELETE;	
+    a.file_operations   =     GP_FILE_OPERATION_DELETE;
     gp_abilities_list_append(list, a);
   }
   return GP_OK;
 }
-		     
-static int camera_exit(Camera *camera, GPContext *context){  
+
+static int camera_exit(Camera *camera, GPContext *context){
   return pccam600_close(camera->port, context);
 }
 
 static int file_list_func (CameraFilesystem *fs, const char *folder,
 			   CameraList *list, void *data, GPContext *context){
-  
+
   Camera *camera = data;
   CameraFileInfo info;
-  int ret,n,i,nr_of_blocks;
+  int n,i,nr_of_blocks;
   int offset = 64;
   char *temp;
   char buffer[512];
@@ -122,16 +110,17 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
   }
   for (n = 0; n != nr_of_blocks; n++)
     {
-      ret = pccam600_read_data(camera->port, buffer);
+      CHECK(pccam600_read_data(camera->port, (unsigned char *)buffer));
       for (i = offset; i <= 512-32; i=i+32)
 	{
 	  memcpy(file_entry,&(buffer)[i],32);
+	  file_entry->name[8] = 0;
 	  /*Fileentry valid? */
-	  if( !((file_entry->state & 0x02) != 2)  && 
+	  if( !((file_entry->state & 0x02) != 2)  &&
 	      !((file_entry->state & 0x08) == 8) )
 	    {
 	      info.file.fields = 0;
-	      temp = &(file_entry->name)[5];
+	      temp = (char *)&(file_entry->name)[5];
 	      if (strncmp(temp,"JPG",3) == 0)
 		{
 		  memcpy(&(file_entry->name)[5],".jpg",4);
@@ -161,14 +150,14 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
 		  info.file.fields = GP_FILE_INFO_WIDTH | GP_FILE_INFO_HEIGHT | GP_FILE_INFO_TYPE;
 		  strcpy(info.file.type, GP_MIME_RAW);
 		}
-	      gp_filesystem_append(fs,folder,file_entry->name,context);
+	      gp_filesystem_append(fs,folder,(char *)file_entry->name,context);
 	      info.preview.fields = 0;
 	      info.file.size = (file_entry->size[1]*256+
 				file_entry->size[0]) * 256;
 	      info.file.permissions = GP_FILE_PERM_READ | GP_FILE_PERM_DELETE;
-	      info.file.fields |= GP_FILE_INFO_SIZE | GP_FILE_INFO_PERMISSIONS 
+	      info.file.fields |= GP_FILE_INFO_SIZE | GP_FILE_INFO_PERMISSIONS
 		|GP_FILE_INFO_TYPE;
-	      ret = gp_filesystem_set_info_noop(fs, folder, file_entry->name, info, context);
+	      CHECK(gp_filesystem_set_info_noop(fs, folder, (char *)file_entry->name, info, context));
 	    }
 	}
 	offset = 0;
@@ -176,16 +165,16 @@ static int file_list_func (CameraFilesystem *fs, const char *folder,
   return GP_OK;
 }
 
-static int camera_get_file (Camera *camera, GPContext *context, int index,  
-			    unsigned char **data, int *size) 
+static int camera_get_file (Camera *camera, GPContext *context, int index,
+			    unsigned char **data, int *size)
 {
   unsigned char buffer[512];
   int nr_of_blocks = 0;
   int n,id,canceled=0;
   int picturebuffersize = 0;
-  int offset = 0;  
+  int offset = 0;
   nr_of_blocks = pccam600_get_file(camera->port,context,index);
-  if (nr_of_blocks < 0) 
+  if (nr_of_blocks < 0)
     return GP_ERROR_FILE_NOT_FOUND;
   picturebuffersize = nr_of_blocks * 512;
   id = gp_context_progress_start(context,nr_of_blocks,_("Downloading file..."));
@@ -210,12 +199,12 @@ static int camera_get_file (Camera *camera, GPContext *context, int index,
 
 static int get_file_func (CameraFilesystem *fs, const char *folder,
 			  const char *filename, CameraFileType type,
-			  CameraFile *file, void *user_data, 
+			  CameraFile *file, void *user_data,
 			  GPContext *context)
 {
   Camera *camera =  user_data;
   unsigned char *data = NULL;
-  int size,ret,index;
+  int size,index;
   size = 0;
   index = gp_filesystem_number(fs, folder, filename, context);
   if (index < 0)
@@ -223,21 +212,20 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
   switch(type)
     {
     case GP_FILE_TYPE_NORMAL:
-      ret=camera_get_file(camera, context, index, &data, &size);
+      CHECK(camera_get_file(camera, context, index, &data, &size));
       break;
     default:
       return GP_ERROR_NOT_SUPPORTED;
     }
-  return gp_file_set_data_and_size(file, data, size);
+  return gp_file_set_data_and_size(file, (char *)data, size);
 }
 
 static int camera_summary(Camera *camera, CameraText *summary, GPContext *context)
 {
   int totalmem;
   int  freemem;
-  int ret;
-  char summary_text[256];  
-  ret = pccam600_get_mem_info(camera->port,context,&totalmem,&freemem);
+  char summary_text[256];
+  CHECK(pccam600_get_mem_info(camera->port,context,&totalmem,&freemem));
   snprintf(summary_text,sizeof(summary_text),
   	   (" Total memory is %8d bytes.\n Free memory is  %8d bytes."),
 	   totalmem,freemem );
@@ -247,19 +235,19 @@ static int camera_summary(Camera *camera, CameraText *summary, GPContext *contex
 
 static int camera_about(Camera *camera, CameraText *about, GPContext *context)
 {
-  strcpy(about->text, 
+  strcpy(about->text,
 	 _("Creative PC-CAM600\nAuthor: Peter Kajberg <pbk@odense.kollegienet.dk>\n"));
   return GP_OK;
 }
 
 static int delete_file_func(CameraFilesystem *fs, const char *folder,
 			    const char *filename, void *data, GPContext *context){
-  int index,ret;
+  int index;
 
   Camera *camera = data;
   index = gp_filesystem_number(fs, folder, filename, context);
   gp_log(GP_LOG_DEBUG,"pccam","deleting '%s' in '%s'.. index:%d",filename, folder,index);
-  ret = pccam600_delete_file(camera->port, context, index);
+  CHECK(pccam600_delete_file(camera->port, context, index));
   return GP_OK;
 }
 
@@ -271,30 +259,26 @@ static CameraFilesystemFuncs fsfuncs = {
 
 int camera_init(Camera *camera, GPContext *context){
   GPPortSettings settings;
-  int ret = 0;
   camera->functions->exit         = camera_exit;
   camera->functions->summary      = camera_summary;
   camera->functions->about        = camera_about;
   gp_log (GP_LOG_DEBUG, "pccam", "Initializing the camera\n");
-  switch (camera->port->type) 
+  switch (camera->port->type)
     {
     case GP_PORT_USB:
-      ret = gp_port_get_settings(camera->port,&settings);
-      if (ret < 0) return ret;
+      CHECK(gp_port_get_settings(camera->port,&settings));
       settings.usb.inep = 0x82;
       settings.usb.outep = 0x03;
       settings.usb.config = 1;
       settings.usb.interface = 1;
       settings.usb.altsetting = 0;
-      ret=gp_port_set_settings(camera->port,settings);
-      if (ret<0) return ret;
+      CHECK(gp_port_set_settings(camera->port,settings));
       break;
     case GP_PORT_SERIAL:
       return GP_ERROR_IO_SUPPORTED_SERIAL;
-    default: 
+    default:
       return GP_ERROR_NOT_SUPPORTED;
-    }    
-  ret = pccam600_init(camera->port, context);
-  if (ret < 0) return ret;
+    }
+  CHECK(pccam600_init(camera->port, context));
   return gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
 }
