@@ -18,7 +18,7 @@
  * Boston, MA  02110-1301  USA
  */
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -30,24 +30,8 @@
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 #define GP_MODULE "pdc700"
 
@@ -191,7 +175,7 @@ static const char *size[]    = {"VGA (640x480)", "XGA (1024x768", NULL};
 static int
 calc_checksum (unsigned char *cmd, unsigned int len)
 {
-	int i;
+	unsigned int i;
 	unsigned char checksum;
 
 	for (checksum = 0, i = 0; i < len; i++)
@@ -233,6 +217,10 @@ pdc700_read (Camera *camera, unsigned char *cmd,
 		return (GP_ERROR_CORRUPTED_DATA);
 	}
 	*b_len = (header[2] << 8) | header [1];
+	if (*b_len > 2048) {
+		GP_DEBUG ("length %d too large", *b_len);
+		return GP_ERROR_CORRUPTED_DATA;
+	}
 
 	/* Read the remaining bytes */
 	CR (gp_port_read (camera->port, (char *)b, *b_len));
@@ -449,7 +437,7 @@ pdc700_picinfo (Camera *camera, unsigned int n, PDCPicInfo *info,
 	/* We don't know about the meaning of buf[0-1] */
 
 	/* Check if this information is about the right picture */
-	if (n != (buf[2] | (buf[3] << 8))) {
+	if (n != (unsigned int)(buf[2] | (buf[3] << 8))) {
 		gp_context_error (context, _("Requested information about "
 			"picture %i (= 0x%x), but got information about "
 			"picture %i back"), n, cmd[4] | (cmd[5] << 8),
@@ -1037,6 +1025,7 @@ which_radio_button (CameraWidget *window, const char *label,
 	if (!gp_widget_changed (child))
 		return -1;
 
+	gp_widget_set_changed (child, FALSE);
 	gp_widget_get_value (child, &value);
 
 	for (i = 0; opt[i]; i++)
@@ -1080,6 +1069,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 	/* Auto poweroff */
 	r = gp_widget_get_child_by_label (window, AUTO_POWEROFF, &child);
 	if ((r == GP_OK) && gp_widget_changed (child)) {
+		gp_widget_set_changed (child, FALSE);
 		gp_widget_get_value (child, &range);
 		CR (pdc700_config (camera, PDC_CONF_POWEROFF,
 				   (unsigned char) range, context));
@@ -1088,6 +1078,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
 	/* Date and time */
 	r = gp_widget_get_child_by_label (window, _("Date and Time"), &child);
 	if ((r == GP_OK) && gp_widget_changed (child)) {
+		gp_widget_set_changed (child, FALSE);
 		gp_widget_get_value (child, &i);
 		if (i != -1)
 		  pdc700_set_date(camera, (time_t) i, context);
