@@ -35,24 +35,7 @@
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-setting.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "ptp.h"
 #include "ptp-bugs.h"
@@ -395,7 +378,7 @@ chdk_get_file_func (CameraFilesystem *fs, const char *folder, const char *filena
 	PTPDataHandler  	handler;
 	char 			*fn;
 
-	fn = malloc(1+strlen(folder)+1+strlen(filename)+1),
+	fn = malloc(1+strlen(folder)+1+strlen(filename)+1);
 	sprintf(fn,"A%s/%s",folder,filename);
 	ptp_init_camerafile_handler (&handler, file);
 	ret = ptp_chdk_download(params, fn, &handler);
