@@ -1,7 +1,7 @@
 /* sipixblink.c
  *
- * Copyright  2002 Vincent Sanders <vince@kyllikki.org>
- * Copyright  2002 Marcus Meissner <marcus@jet.franken.de>
+ * Copyright 2002 Vincent Sanders <vince@kyllikki.org>
+ * Copyright 2002 Marcus Meissner <marcus@jet.franken.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 /*
  * This library is unfinished! -Marcus
@@ -30,19 +30,8 @@
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
+
 
 int
 camera_id (CameraText *id)
@@ -782,7 +771,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	gp_file_append(file, xdata, picsize);
 	free(xdata);
 	gp_file_set_mime_type (file, GP_MIME_UNKNOWN);
-	gp_file_set_name (file, filename);
 	return (GP_OK);
 }
 
@@ -885,6 +873,7 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	CameraFileInfo  info;
 	unsigned char reply[6];
 	int i, numpics, ret;
+	char fn[20];
 
 	numpics = _get_number_images(camera);
 	if (numpics < GP_OK)
@@ -893,12 +882,12 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 #if 1
 	for (i=0;i<numpics;i++) {
 		/* we also get the fs info for free, so just set it */
-		info.file.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_NAME |
+		info.file.fields = GP_FILE_INFO_TYPE |
 				GP_FILE_INFO_WIDTH | GP_FILE_INFO_HEIGHT |
 				GP_FILE_INFO_SIZE;
 		strcpy(info.file.type,GP_MIME_UNKNOWN);
-		sprintf(info.file.name,"blink%03i.raw",i);
-		ret = gp_filesystem_append(fs, "/", info.file.name, context);
+		sprintf(fn,"blink%03i.raw",i);
+		ret = gp_filesystem_append(fs, "/", fn, context);
 		if (ret != GP_OK)
 			return ret;
 		do {
@@ -940,7 +929,7 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 			(reply[2] << 8)	|
 			(reply[3] << 16)|
 			(reply[4] << 24);
-		ret = gp_filesystem_set_info_noop(fs, "/", info, context);
+		ret = gp_filesystem_set_info_noop(fs, "/", fn, info, context);
 		if (ret != GP_OK)
 			return ret;
 	}
