@@ -29,8 +29,8 @@
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
-#include <bayer.h>
-#include <gamma.h>
+#include <libgphoto2/bayer.h>
+#include <libgphoto2/gamma.h>
 
 #include "ultrapocket.h"
 #include "smal.h"
