@@ -26,7 +26,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include <bayer.h>
+#include <libgphoto2/bayer.h>
 
 #include <gphoto2/gphoto2.h>
 
