@@ -30,34 +30,20 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+
 #include <gphoto2/gphoto2.h>
-#include "gphoto2-endian.h"
+#include "libgphoto2/gphoto2-endian.h"
+
+#include "libgphoto2/i18n.h"
 
 #include "spca50x.h"
 #include "spca50x-sdram.h"
 #include "spca50x-registers.h"
 #include "spca50x-avi-header.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
 
 #define GP_MODULE "spca50x"
+
 static int spca50x_mode_set_idle (CameraPrivateLibrary * lib);
 static int spca50x_is_idle (CameraPrivateLibrary * lib);
 static int spca50x_mode_set_download (CameraPrivateLibrary * lib);
@@ -123,7 +109,7 @@ spca50x_sdram_get_file_count_and_fat_count (CameraPrivateLibrary * lib,
 		CHECK (gp_port_usb_msg_read
 				(lib->gpdev, 0, 0, 0xe15,
 				 (char *) & lib->num_files_on_sdram, 1));
-		LE32TOH (lib->num_files_on_sdram);
+		le32toh (lib->num_files_on_sdram);
 
 		/*  get fatscount */
 		CHECK (gp_port_usb_msg_write
