@@ -23,23 +23,12 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
 #include <gphoto2/gphoto2-library.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2/i18n.h"
 
 #include "stv0674.h"
 #include "library.h"
