@@ -1,21 +1,13 @@
 var gphoto2_port_8c =
 [
     [ "_GPPortPrivateCore", "struct__GPPortPrivateCore.html", "struct__GPPortPrivateCore" ],
-    [ "_", "gphoto2-port_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
-    [ "_DEFAULT_SOURCE", "gphoto2-port_8c.html#a8fb447618db946a9e2a596d9ea18763f", null ],
-    [ "CHECK_INIT", "gphoto2-port_8c.html#a7dd9e079511891ec9996ebb25c0e6814", null ],
-    [ "CHECK_RESULT", "gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
-    [ "CHECK_SUPP", "gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a", null ],
     [ "FAST_TIMEOUT", "gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525", null ],
-    [ "LOG_DATA", "gphoto2-port_8c.html#a828c4f99cd2fcdbf9b83793b1c7e7ccb", null ],
-    [ "N_", "gphoto2-port_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
-    [ "ngettext", "gphoto2-port_8c.html#a3011b7cb854d99053a2d68ff760179b4", null ],
     [ "gp_port_check_int", "gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277", null ],
     [ "gp_port_check_int_fast", "gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c", null ],
     [ "gp_port_close", "gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e", null ],
     [ "gp_port_flush", "gphoto2-port_8c.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d", null ],
     [ "gp_port_free", "gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5", null ],
-    [ "gp_port_get_error", "gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828", null ],
+    [ "gp_port_get_error", "gphoto2-port_8c.html#a8fd66df2fcf8598f1765f429d746284e", null ],
     [ "gp_port_get_info", "gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a", null ],
     [ "gp_port_get_pin", "gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62", null ],
     [ "gp_port_get_settings", "gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0", null ],
@@ -45,11 +37,5 @@ var gphoto2_port_8c =
     [ "gp_port_usb_msg_interface_write", "gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305", null ],
     [ "gp_port_usb_msg_read", "gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6", null ],
     [ "gp_port_usb_msg_write", "gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d", null ],
-    [ "gp_port_write", "gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897", null ],
-    [ "description", "gphoto2-port_8c.html#a68344fa88cf4e86b5079fd69a5c22d57", null ],
-    [ "description_long", "gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca", null ],
-    [ "description_short", "gphoto2-port_8c.html#afac0b65253b3a37c961828e88b453733", null ],
-    [ "level", "gphoto2-port_8c.html#af3b9610f316d951aa2a99b225dba748a", null ],
-    [ "number", "gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54", null ],
-    [ "pin", "gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e", null ]
+    [ "gp_port_write", "gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897", null ]
 ];
\ No newline at end of file
