@@ -1,7 +1,6 @@
 var gphoto2_widget_8c =
 [
-    [ "_CameraWidget", "struct__CameraWidget.html", "struct__CameraWidget" ],
-    [ "_DARWIN_C_SOURCE", "gphoto2-widget_8c.html#affdcd7001fd98e86452e182eb8cb8458", null ],
+    [ "_CameraWidget", "struct__CameraWidget.html", null ],
     [ "gp_widget_add_choice", "gphoto2-widget_8c.html#ae41c7eb76c0bb21770879ad8e1dc58b9", null ],
     [ "gp_widget_append", "gphoto2-widget_8c.html#ab3365698f977ba94534148d1df5eb9d8", null ],
     [ "gp_widget_changed", "gphoto2-widget_8c.html#adaf6cc55afadae959d07adebecc85c65", null ],
