@@ -1,4 +1,4 @@
-/** \file
+/** \file bayer.h
  *
  * \author Copyright 2001 Lutz Mueller <lutz@users.sf.net>
  *
@@ -21,24 +21,12 @@
  * Boston, MA  02110-1301  USA
  */
 
-#ifndef __BAYER_H__
-#define __BAYER_H__
+#ifndef LIBGPHOTO2_BAYER_H
+#define LIBGPHOTO2_BAYER_H
+
+
+#include "libgphoto2/bayer-types.h"
 
-/**
- * \brief how the bayer CCD array is laid out
- *
- * This enumeration defines how the CCD bayer array is laid out.
- */
-typedef enum {
-	BAYER_TILE_RGGB = 0,			/**< \brief raster is RG,GN */
-	BAYER_TILE_GRBG = 1,			/**< \brief raster is GR,BG */
-	BAYER_TILE_BGGR = 2,			/**< \brief raster is BG,GR */
-	BAYER_TILE_GBRG = 3,			/**< \brief raster is RG,GB */
-	BAYER_TILE_RGGB_INTERLACED = 4,		/**< \brief scanline order: R1,G1,R2,G2,...,G1,B1,G2,B2,... */
-	BAYER_TILE_GRBG_INTERLACED = 5,		/**< \brief scanline order: G1,R1,R2,G2,...,B1,G1,B2,G2,... */
-	BAYER_TILE_BGGR_INTERLACED = 6,		/**< \brief scanline order: B1,G1,R2,G2,...,G1,R1,G2,R2,... */
-	BAYER_TILE_GBRG_INTERLACED = 7,		/**< \brief scanline order: G1,B1,G2,B2,...,R1,G1,R2,G2,... */
-} BayerTile;
 
 int gp_bayer_expand (unsigned char *input, int w, int h, unsigned char *output,
                      BayerTile tile);
@@ -58,4 +46,4 @@ int gp_ahd_decode (unsigned char *input, int w, int h, unsigned char *output,
 		     BayerTile tile);
 int gp_ahd_interpolate (unsigned char *image, int w, int h, BayerTile tile);
 
-#endif /* __BAYER_H__ */
+#endif /* !defined(LIBGPHOTO2_BAYER_H) */
