@@ -9,17 +9,18 @@
  * version 2 of the License, or (at your option) any later version.
  *
  * \par
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
+#define _DARWIN_C_SOURCE
 #include "config.h"
 #include <gphoto2/gphoto2-widget.h>
 
@@ -29,8 +30,6 @@
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-port-log.h>
 
-#define CHECK_NULL(r)        {if (!(r)) return (GP_ERROR_BAD_PARAMETERS);}
-
 /**
  * CameraWidget:
  *
@@ -55,8 +54,8 @@ struct _CameraWidget {
 	int     choice_count;
 
 	/* For Range */
-	float   min; 
-	float   max; 
+	float   min;
+	float   max;
 	float   increment;
 
 	/* Child info */
@@ -87,24 +86,23 @@ struct _CameraWidget {
  *
  * @param type the type
  * @param label the label
- * @param widget 
+ * @param widget
  * @return a gphoto2 error code.
- * 
+ *
  **/
 int
-gp_widget_new (CameraWidgetType type, const char *label, 
-		   CameraWidget **widget) 
+gp_widget_new (CameraWidgetType type, const char *label,
+		   CameraWidget **widget)
 {
 	static int i = 0;
 
-	CHECK_NULL (label && widget);
+	C_PARAMS (label && widget);
 
-	*widget = (CameraWidget*) malloc (sizeof (CameraWidget));
-	memset (*widget, 0, sizeof (CameraWidget));
+	C_MEM (*widget = calloc (1, sizeof (CameraWidget)));
 
 	(*widget)->type = type;
 	strcpy ((*widget)->label, label);
-	
+
 	/* set the value to nothing */
 	(*widget)->value_int    	= 0;
         (*widget)->value_float  	= 0.0;
@@ -129,13 +127,13 @@ gp_widget_new (CameraWidgetType type, const char *label,
  *
  * @param widget the #CameraWidget to be freed
  * @return a gphoto2 error code.
- * 
+ *
  **/
 int
 gp_widget_free (CameraWidget *widget)
 {
 	int x;
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	/* Free children recursively */
 	if ((widget->type == GP_WIDGET_WINDOW) ||
@@ -147,9 +145,7 @@ gp_widget_free (CameraWidget *widget)
 	for (x = 0; x < widget->choice_count; x++)
 		free (widget->choice[x]);
 	free (widget->choice);
-
-        if (widget->value_string)
-		free (widget->value_string);
+	free (widget->value_string);
 	free (widget);
 	return (GP_OK);
 }
@@ -162,9 +158,9 @@ gp_widget_free (CameraWidget *widget)
  *
  **/
 int
-gp_widget_ref (CameraWidget *widget) 
+gp_widget_ref (CameraWidget *widget)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->ref_count += 1;
 
@@ -179,9 +175,9 @@ gp_widget_ref (CameraWidget *widget)
  *
  **/
 int
-gp_widget_unref (CameraWidget *widget) 
+gp_widget_unref (CameraWidget *widget)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->ref_count -= 1;
 
@@ -202,7 +198,7 @@ gp_widget_unref (CameraWidget *widget)
 int
 gp_widget_get_info (CameraWidget *widget, const char **info)
 {
-	CHECK_NULL (widget && info);
+	C_PARAMS (widget && info);
 
 	*info = widget->info;
 	return (GP_OK);
@@ -220,7 +216,7 @@ gp_widget_get_info (CameraWidget *widget, const char **info)
 int
 gp_widget_set_info (CameraWidget *widget, const char *info)
 {
-	CHECK_NULL (widget && info);
+	C_PARAMS (widget && info);
 
 	strcpy (widget->info, info);
 	return (GP_OK);
@@ -237,7 +233,7 @@ gp_widget_set_info (CameraWidget *widget, const char *info)
 int
 gp_widget_get_name (CameraWidget *widget, const char **name)
 {
-	CHECK_NULL (widget && name);
+	C_PARAMS (widget && name);
 
 	*name = widget->name;
 	return (GP_OK);
@@ -254,7 +250,7 @@ gp_widget_get_name (CameraWidget *widget, const char **name)
 int
 gp_widget_set_name (CameraWidget *widget, const char *name)
 {
-	CHECK_NULL (widget && name);
+	C_PARAMS (widget && name);
 
 	strcpy (widget->name, name);
 	return (GP_OK);
@@ -266,14 +262,14 @@ gp_widget_set_name (CameraWidget *widget, const char *name)
  * \brief Retrieves the unique id of the #CameraWidget
  *
  * @param widget a #CameraWidget
- * @param id 
+ * @param id
  * @return a gphoto2 error code.
  *
  **/
 int
 gp_widget_get_id (CameraWidget *widget, int *id)
 {
-	CHECK_NULL (widget && id);
+	C_PARAMS (widget && id);
 
 	*id = widget->id;
 	return (GP_OK);
@@ -286,14 +282,14 @@ gp_widget_get_id (CameraWidget *widget, int *id)
  * @param changed a boolean whether we changed or not
  * @return a gphoto2 error code
  *
- * Sets the changed of the CameraWidget depending on 
+ * Sets the changed of the CameraWidget depending on
  * the changed parameter.
  *
  **/
 int
 gp_widget_set_changed (CameraWidget *widget, int changed)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->changed = changed;
 	return (GP_OK);
@@ -306,7 +302,7 @@ gp_widget_set_changed (CameraWidget *widget, int changed)
  * @param changed a boolean whether we are readonly or not
  * @return a gphoto2 error code
  *
- * Sets the readonly of the CameraWidget depending on 
+ * Sets the readonly of the CameraWidget depending on
  * the changed parameter.
  *
  * Only useful when called from the camera driver.
@@ -314,7 +310,7 @@ gp_widget_set_changed (CameraWidget *widget, int changed)
 int
 gp_widget_set_readonly (CameraWidget *widget, int readonly)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	widget->readonly = readonly;
 	return (GP_OK);
@@ -329,9 +325,9 @@ gp_widget_set_readonly (CameraWidget *widget, int readonly)
  *
  **/
 int
-gp_widget_get_readonly (CameraWidget *widget, int *readonly) 
+gp_widget_get_readonly (CameraWidget *widget, int *readonly)
 {
-	CHECK_NULL (widget && readonly);
+	C_PARAMS (widget && readonly);
 
 	*readonly = widget->readonly;
 	return (GP_OK);
@@ -346,9 +342,9 @@ gp_widget_get_readonly (CameraWidget *widget, int *readonly)
  *
  **/
 int
-gp_widget_get_type (CameraWidget *widget, CameraWidgetType *type) 
+gp_widget_get_type (CameraWidget *widget, CameraWidgetType *type)
 {
-	CHECK_NULL (widget && type);
+	C_PARAMS (widget && type);
 
 	*type = widget->type;
 	return (GP_OK);
@@ -363,9 +359,9 @@ gp_widget_get_type (CameraWidget *widget, CameraWidgetType *type)
  *
  **/
 int
-gp_widget_get_label (CameraWidget *widget, const char **label) 
+gp_widget_get_label (CameraWidget *widget, const char **label)
 {
-	CHECK_NULL (widget && label);
+	C_PARAMS (widget && label);
 
 	*label = widget->label;
 	return (GP_OK);
@@ -375,7 +371,7 @@ gp_widget_get_label (CameraWidget *widget, const char **label)
  * \brief Sets the value of the widget
  *
  * @param widget a #CameraWidget
- * @param value 
+ * @param value
  * @return a gphoto2 error code.
  *
  * Please pass
@@ -386,9 +382,9 @@ gp_widget_get_label (CameraWidget *widget, const char **label)
  *
  **/
 int
-gp_widget_set_value (CameraWidget *widget, const void *value) 
+gp_widget_set_value (CameraWidget *widget, const void *value)
 {
-	CHECK_NULL (widget && value);
+	C_PARAMS (widget && value);
 
         switch (widget->type) {
 	case GP_WIDGET_BUTTON:
@@ -397,9 +393,9 @@ gp_widget_set_value (CameraWidget *widget, const void *value)
 	case GP_WIDGET_MENU:
 	case GP_WIDGET_RADIO:
         case GP_WIDGET_TEXT:
-		gp_log (GP_LOG_DEBUG, "gphoto2-widget", "Setting value of widget "
-			"'%s' to '%s'...", widget->label, (char*) value);
-			if (widget->value_string) {
+		GP_LOG_D ("Setting value of widget '%s' to '%s'...",
+			widget->label, (char*) value);
+		if (widget->value_string) {
                 	if (strcmp (widget->value_string, (char*) value))
                     		widget->changed = 1;
                 	free (widget->value_string);
@@ -436,9 +432,9 @@ gp_widget_set_value (CameraWidget *widget, const void *value)
  *
  **/
 int
-gp_widget_get_value (CameraWidget *widget, void *value) 
+gp_widget_get_value (CameraWidget *widget, void *value)
 {
-	CHECK_NULL (widget && value);
+	C_PARAMS (widget && value);
 
         switch (widget->type) {
 	case GP_WIDGET_BUTTON:
@@ -472,22 +468,15 @@ gp_widget_get_value (CameraWidget *widget, void *value)
  *
  **/
 int
-gp_widget_append (CameraWidget *widget, CameraWidget *child) 
+gp_widget_append (CameraWidget *widget, CameraWidget *child)
 {
-	CameraWidget **newlist;
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	/* Return if they can't have any children */
-        if ((widget->type != GP_WIDGET_WINDOW) && 
-	    (widget->type != GP_WIDGET_SECTION))
-		return (GP_ERROR_BAD_PARAMETERS);
+        C_PARAMS ((widget->type == GP_WIDGET_WINDOW) ||
+                  (widget->type == GP_WIDGET_SECTION));
 
-	if (widget->children_count)
-		newlist = realloc(widget->children,sizeof(CameraWidget*)*(widget->children_count+1));
-	else
-		newlist = malloc(sizeof(CameraWidget*));
-	if (!newlist) return (GP_ERROR_NO_MEMORY);
-	widget->children = newlist;
+	C_MEM (widget->children = realloc(widget->children, sizeof(CameraWidget*)*(widget->children_count+1)));
 	widget->children[widget->children_count] = child;
 	widget->children_count += 1;
 	child->parent = widget;
@@ -505,24 +494,17 @@ gp_widget_append (CameraWidget *widget, CameraWidget *child)
  *
  **/
 int
-gp_widget_prepend (CameraWidget *widget, CameraWidget *child) 
+gp_widget_prepend (CameraWidget *widget, CameraWidget *child)
 {
 	int x;
-	CameraWidget**	newlist;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	/* Return if they can't have any children */
-	if ((widget->type != GP_WIDGET_WINDOW) && 
-	    (widget->type != GP_WIDGET_SECTION))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS ((widget->type == GP_WIDGET_WINDOW) ||
+		  (widget->type == GP_WIDGET_SECTION));
 
-	if (widget->children_count)
-		newlist = realloc(widget->children,sizeof(CameraWidget*)*(widget->children_count+1));
-	else
-		newlist = malloc(sizeof(CameraWidget*));
-	if (!newlist) return (GP_ERROR_NO_MEMORY);
-	widget->children = newlist;
+	C_MEM (widget->children = realloc(widget->children, sizeof(CameraWidget*)*(widget->children_count+1)));
 
 	/* Shift down 1 */
 	for (x = widget->children_count; x > 0; x--)
@@ -545,9 +527,9 @@ gp_widget_prepend (CameraWidget *widget, CameraWidget *child)
  *
  **/
 int
-gp_widget_count_children (CameraWidget *widget) 
+gp_widget_count_children (CameraWidget *widget)
 {
-	CHECK_NULL (widget);
+	C_PARAMS (widget);
 
 	return (widget->children_count);
 }
@@ -562,13 +544,11 @@ gp_widget_count_children (CameraWidget *widget)
  *
  **/
 int
-gp_widget_get_child (CameraWidget *widget, int child_number, 
-		     CameraWidget **child) 
+gp_widget_get_child (CameraWidget *widget, int child_number,
+		     CameraWidget **child)
 {
-	CHECK_NULL (widget && child);
-
-	if (child_number >= widget->children_count)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && child);
+	C_PARAMS (child_number < widget->children_count);
 
 	*child = widget->children[child_number];
 	return (GP_OK);
@@ -584,12 +564,12 @@ gp_widget_get_child (CameraWidget *widget, int child_number,
  *
  **/
 int
-gp_widget_get_child_by_label (CameraWidget *widget, const char *label, 
+gp_widget_get_child_by_label (CameraWidget *widget, const char *label,
 			      CameraWidget **child)
 {
 	int x;
 
-	CHECK_NULL (widget && label && child);
+	C_PARAMS (widget && label && child);
 
 	if (strcmp (widget->label, label) == 0) {
 		*child = widget;
@@ -599,8 +579,8 @@ gp_widget_get_child_by_label (CameraWidget *widget, const char *label,
 	for (x = 0; x < widget->children_count; x++) {
 		int result;
 		CameraWidget *child_rec;
-		
-		result = gp_widget_get_child_by_label (widget->children[x], 
+
+		result = gp_widget_get_child_by_label (widget->children[x],
 						       label, &child_rec);
 		if (result == GP_OK) {
 			*child = child_rec;
@@ -621,22 +601,22 @@ gp_widget_get_child_by_label (CameraWidget *widget, const char *label,
  *
  **/
 int
-gp_widget_get_child_by_id (CameraWidget *widget, int id, CameraWidget **child) 
+gp_widget_get_child_by_id (CameraWidget *widget, int id, CameraWidget **child)
 {
 	int x;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	if (widget->id == id) {
 		*child = widget;
 		return (GP_OK);
 	}
-	
+
 	for (x = 0; x < widget->children_count; x++) {
 		int result;
 		CameraWidget *child_rec;
-		
-		result = gp_widget_get_child_by_id (widget->children[x], id, 
+
+		result = gp_widget_get_child_by_id (widget->children[x], id,
 						    &child_rec);
 		if (result == GP_OK) {
 			*child = child_rec;
@@ -661,17 +641,17 @@ gp_widget_get_child_by_name (CameraWidget *widget, const char *name,
 {
 	int x;
 
-	CHECK_NULL (widget && child);
+	C_PARAMS (widget && child);
 
 	if (!strcmp (widget->name, name)) {
 		*child = widget;
 		return (GP_OK);
 	}
-	
+
 	for (x = 0; x < widget->children_count; x++) {
 		int result;
 		CameraWidget *child_rec;
-		
+
 		result = gp_widget_get_child_by_name (widget->children[x], name,
 						      &child_rec);
 		if (result == GP_OK) {
@@ -694,7 +674,7 @@ gp_widget_get_child_by_name (CameraWidget *widget, const char *name,
 int
 gp_widget_get_parent (CameraWidget *widget, CameraWidget **parent)
 {
-	CHECK_NULL (widget && parent);
+	C_PARAMS (widget && parent);
 
 	*parent = widget->parent;
 
@@ -710,11 +690,11 @@ gp_widget_get_parent (CameraWidget *widget, CameraWidget **parent)
  *
  **/
 int
-gp_widget_get_root (CameraWidget *widget, CameraWidget **root) 
+gp_widget_get_root (CameraWidget *widget, CameraWidget **root)
 {
-	CHECK_NULL (widget && root);
+	C_PARAMS (widget && root);
 
-	if (widget->parent) 
+	if (widget->parent)
 		return (gp_widget_get_root (widget->parent, root));
 	else {
 		*root = widget;
@@ -735,10 +715,8 @@ gp_widget_get_root (CameraWidget *widget, CameraWidget **root)
 int
 gp_widget_set_range (CameraWidget *range, float min, float max, float increment)
 {
-	CHECK_NULL (range);
-	
-	if (range->type != GP_WIDGET_RANGE)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (range);
+	C_PARAMS (range->type == GP_WIDGET_RANGE);
 
 	range->min = min;
 	range->max = max;
@@ -758,12 +736,11 @@ gp_widget_set_range (CameraWidget *range, float min, float max, float increment)
  *
  **/
 int
-gp_widget_get_range (CameraWidget *range, float *min, float *max, 
-		     float *increment) 
+gp_widget_get_range (CameraWidget *range, float *min, float *max,
+		     float *increment)
 {
-	CHECK_NULL (range && min && max && increment);
-	if (range->type != GP_WIDGET_RANGE)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (range && min && max && increment);
+	C_PARAMS (range->type == GP_WIDGET_RANGE);
 
 	*min = range->min;
 	*max = range->max;
@@ -781,22 +758,13 @@ gp_widget_get_range (CameraWidget *range, float *min, float *max,
  *
  **/
 int
-gp_widget_add_choice (CameraWidget *widget, const char *choice) 
+gp_widget_add_choice (CameraWidget *widget, const char *choice)
 {
-	char **choices;
-	CHECK_NULL (widget && choice);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && choice);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
 
-	if (widget->choice_count) {
-		choices = realloc (widget->choice, sizeof(char*)*(widget->choice_count+1));
-	} else {
-		choices = malloc (sizeof(char*));
-	}
-	if (!choices) return (GP_ERROR_NO_MEMORY);
-
-	widget->choice = choices;
+	C_MEM (widget->choice = realloc (widget->choice, sizeof(char*)*(widget->choice_count+1)));
 	widget->choice[widget->choice_count] = strdup(choice);
 	widget->choice_count += 1;
 	return (GP_OK);
@@ -807,15 +775,14 @@ gp_widget_add_choice (CameraWidget *widget, const char *choice)
  *
  * @param widget a #CameraWidget of type GP_WIDGET_RADIO or GP_WIDGET_MENU
  * @return a gphoto2 error code or number of choices.
- * 
+ *
  **/
 int
-gp_widget_count_choices (CameraWidget *widget) 
+gp_widget_count_choices (CameraWidget *widget)
 {
-	CHECK_NULL (widget);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
 
 	return (widget->choice_count);
 }
@@ -830,16 +797,13 @@ gp_widget_count_choices (CameraWidget *widget)
  *
  **/
 int
-gp_widget_get_choice (CameraWidget *widget, int choice_number, 
-		      const char **choice) 
+gp_widget_get_choice (CameraWidget *widget, int choice_number,
+		      const char **choice)
 {
-	CHECK_NULL (widget && choice);
-	if ((widget->type != GP_WIDGET_RADIO) &&
-	    (widget->type != GP_WIDGET_MENU))
-		return (GP_ERROR_BAD_PARAMETERS);
-
-	if (choice_number >= widget->choice_count)
-		return (GP_ERROR_BAD_PARAMETERS);
+	C_PARAMS (widget && choice);
+	C_PARAMS ((widget->type == GP_WIDGET_RADIO) ||
+		  (widget->type == GP_WIDGET_MENU));
+	C_PARAMS (choice_number < widget->choice_count);
 
 	*choice = widget->choice[choice_number];
 	return (GP_OK);
@@ -852,18 +816,14 @@ gp_widget_get_choice (CameraWidget *widget, int choice_number,
  * @return a gphoto2 error code or changed flag.
  *
  * Returns 1 if the state of the #CameraWidget has been changed or 0 if not.
- * In addition, it resets the changed flag to 0.
+ *
+ * Note: this formerly cleared the changed state. It no longer does with 2.5.11.
  *
  **/
 int
-gp_widget_changed (CameraWidget *widget) 
+gp_widget_changed (CameraWidget *widget)
 {
-        int val;
+	C_PARAMS (widget);
 
-	CHECK_NULL (widget);
-
-        val = widget->changed;
-        widget->changed = 0;
-
-        return (val);
+        return widget->changed;
 }
