@@ -16,15 +16,17 @@
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
-#include "jpeg.h"
+#include "libgphoto2/jpeg.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 #include <gphoto2/gphoto2-file.h>
 
 /* call example:nullpictureabort(picture,"Picture",0); */
@@ -94,7 +96,7 @@ void gpi_jpeg_chunk_print(chunk *mychunk)
 /*    printf("Size=%i\n", mychunk->size); */
     nullpointerabortvoid(mychunk, "Chunk");
     for (x=0; x<mychunk->size; x++)
-        printf("%hX ", mychunk->data[x]);
+        printf("%hhX ", mychunk->data[x]);
     printf("\n");
 }
 
@@ -128,9 +130,9 @@ char gpi_jpeg_findactivemarker(char *id, int *location, chunk *picture)
     return 0;
 }
 
-char *gpi_jpeg_markername(int c)
+char *gpi_jpeg_markername(unsigned int c)
 {
-    int x;
+    unsigned int x;
 /*    printf("searching for marker %X in list\n",c); */
 /*    printf("%i\n", sizeof(markers)); */
     for (x=0; x<countof(JPEG_MARKERS); x++)
@@ -291,7 +293,7 @@ void gpi_jpeg_print_quantization_table(jpeg_quantization_table *table)
 }
 
 
-chunk *gpi_jpeg_make_quantization(jpeg_quantization_table *table, char number)
+chunk *gpi_jpeg_make_quantization(const jpeg_quantization_table *table, char number)
 {
     chunk *temp;
     char x,y,z,c;
@@ -340,7 +342,7 @@ jpeg_quantization_table *gpi_jpeg_quantization2table(chunk *qmarker)
 jpeg *gpi_jpeg_header(int width, int height,
     char vh1, char vh2, char vh3,
     char q1, char q2, char q3,
-    jpeg_quantization_table *quant1, jpeg_quantization_table *quant2,
+    const jpeg_quantization_table *quant1, const jpeg_quantization_table *quant2,
     char huffset1, char huffset2, char huffset3,
     chunk *huff1, chunk *huff2, chunk *huff3, chunk *huff4)
 {
