@@ -33,19 +33,7 @@
 
 #include <gphoto2/gphoto2-port-result.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (GETTEXT_PACKAGE, String)
-#  ifdef gettext_noop
-#      define N_(String) gettext_noop (String)
-#  else
-#      define N_(String) (String)
-#  endif
-#else
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "libgphoto2_port/i18n.h"
 
 #ifndef DISABLE_DEBUGGING
 /**
