@@ -52,9 +52,9 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "__stdint_8h_source.html",
-"gphoto2-file_8c.html#a0376d5d1c7af0edde33cdbe7f3d2eb1e",
-"gphoto2-port-info_8h.html",
-"gphoto2-widget_8h.html#a8c7e7c5b04d992022d9a821a0d3f9c30a82fd9cfdb47df56973dfebaa1ebb5356"
+"gphoto2-endian_8h_source.html",
+"gphoto2-port-info-list_8h.html#ab60c983825bfa2b6aa2fcb1e1a32b08f",
+"gphoto2-widget_8h.html#a7a547c3a01c9ba10c8552187aca0a43f"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
